Method: InterMine::Lists::ListManager#intersection_of
- Defined in:
- lib/intermine/lists.rb
#intersection_of(lists = [], tags = [], name = nil, description = nil) ⇒ Object
Create a new list in the webservice from the intersection of two or more lists, and return a List object that represents it.
See ListManager#create_list for an explanation of tags, name and description
549 550 551 |
# File 'lib/intermine/lists.rb', line 549 def intersection_of(lists=[], =[], name=nil, description=nil) do_commutative_list_operation(Service::LIST_INTERSECTION_PATH, "Intersection", lists, , name, description) end |